package com.example.di

import com.example.config.JwtConfig
import com.example.repository.AuthRepository
import com.example.repository.AuthRepositoryImpl
import com.example.security.JwtManager
import com.example.service.AuthServiceImpl
import io.ktor.server.application.*
import org.koin.core.module.Module
import org.koin.dsl.module

fun configureDependencyInjection(application: Application): Module{
    return module {
        single<JwtConfig> { provideJwtConfiguration(application.environment) }
        single<JwtManager> { JwtManager(get()) }
        single<AuthRepository> { AuthRepositoryImpl() }
        single<AuthServiceImpl> { AuthServiceImpl(get(), get()) }
    }
}

fun provideJwtConfiguration(environment: ApplicationEnvironment): JwtConfig{
    return JwtConfig(
        jwtIssue = environment.config.property("jwt.issue").toString(),
        jwtAudience = environment.config.property("jwt.audience").toString(),
        jwtSecret = environment.config.property("jwt.secret").toString()
    )
}