package com.example.route

import com.example.common.Either
import com.example.config.JwtConfig
import com.example.dto.request.LoginRequest
import com.example.repository.AuthRepositoryImpl
import com.example.security.JwtManager
import com.example.service.AuthServiceImpl
import com.example.service.exception.ErrorService
import io.ktor.http.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject


fun Route.authRoute(){

    val authServiceImpl: AuthServiceImpl by inject()

    route("/auth"){
        post("/login") {
            val loginRequest = call.receive<LoginRequest>()
            val result = authServiceImpl.login(loginRequest)
            when(result){
                is Either.Left -> {
                    when(result.data){
                        ErrorService.NOT_FOUND -> {
                            call.respond(HttpStatusCode.NotFound)
                        }
                        ErrorService.UNAUTHORIZED -> {
                            call.respond(HttpStatusCode.Unauthorized)
                        }
                    }
                }
                is Either.Right -> {
                    call.respond(HttpStatusCode.OK, result.data)
                }
            }
        }
    }
}